@@ -6,18 +6,16 @@
 (*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
 (*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
 (*                                                                     *)
-(*  Copyright 1999-2004,                                               *)
+(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
 (*  Institut National de Recherche en Informatique et en Automatique.  *)
 (*  Distributed only by permission.                                    *)
 (*                                                                     *)
 (***********************************************************************)
 
-(* $Id: region.mli,v 1.7 2004/09/07 07:31:02 weis Exp $ *)
+val check : int -> int -> int -> int -> unit
+    (* [check width height x y] checks whether the point (x,y) is in the
+       region of (0,0)-([width]-1,[height]-1).
+       If not, it raises [Image.Out_of_image]. *)
 
-val check : int -> int -> int -> int -> unit;;
-    (** [check width height x y] checks whether the point (x,y) is in the
-       region of (0, 0) - ([width] - 1, [height] - 1).
-       If not, it raises [Images.Out_of_image]. *)
-
-val error : (unit -> unit) ref;;
+val error : (unit -> unit) ref
     (* just for system use *)
